@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/admin/user.php,v 1.47.10.7 2006/01/01 21:28:05 jan Exp $
+ * $Horde: horde/admin/user.php,v 1.47.10.10 2007/01/02 13:54:03 jan Exp $
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -23,21 +23,25 @@ $auth = &Auth::singleton($conf['auth']['driver']);
 
 if ($conf['signup']['allow'] && $conf['signup']['approve']) {
     require_once 'Horde/Auth/Signup.php';
-    $signup = &Auth_Signup::singleton();
+    $signup = new Auth_Signup();
 }
 
-$vars = &Variables::getDefaultVariables();
+$vars = Variables::getDefaultVariables();
 $addForm = &new Horde_Form($vars, _("Add a new user:"), 'adduser');
 $addForm->setButtons(_("Add user"), _("Reset"));
 
 $vars->set('form', 'add');
 $addForm->addHidden('', 'form', 'text', true, true);
-$addForm->addVariable(_("Username"), 'user_name', 'text', true);
-$addForm->addVariable(_("Password"), 'password', 'passwordconfirm', false, false, _("type the password twice to confirm"));
 
 /* Use hooks get any extra fields for new accounts. */
 $extra = Horde::callHook('_horde_hook_signup_getextra');
 if (!is_a($extra, 'PEAR_Error') && !empty($extra)) {
+    if (!isset($extra['user_name'])) {
+        $addForm->addVariable(_("Username"), 'user_name', 'text', true);
+    }
+    if (!isset($extra['password'])) {
+        $addForm->addVariable(_("Password"), 'password', 'passwordconfirm', false, false, _("type the password twice to confirm"));
+    }
     foreach ($extra as $field_name => $field) {
         $readonly = isset($field['readonly']) ? $field['readonly'] : null;
         $desc = isset($field['desc']) ? $field['desc'] : null;
@@ -45,6 +49,9 @@ if (!is_a($extra, 'PEAR_Error') && !empty($extra)) {
 
         $addForm->addVariable($field['label'], 'extra[' . $field_name . ']', $field['type'], $field['required'], $readonly, $desc, $field_params);
     }
+} else {
+    $addForm->addVariable(_("Username"), 'user_name', 'text', true);
+    $addForm->addVariable(_("Password"), 'password', 'passwordconfirm', false, false, _("type the password twice to confirm"));
 }
 
 
@@ -138,6 +145,7 @@ case 'update':
     $fullname = Util::getPost('user_fullname');
     $email = Util::getPost('user_email');
 
+    $result = false;
     if ($auth->hasCapability('update')) {
         $user_pass_1 = Util::getPost('user_pass_1');
         $user_pass_2 = Util::getPost('user_pass_2');
@@ -155,7 +163,7 @@ case 'update':
         }
     }
 
-    if (isset($result) && is_a($result, 'PEAR_Error')) {
+    if (is_a($result, 'PEAR_Error')) {
         $notification->push(sprintf(_("There was a problem updating \"%s\": %s"),
                                     $user_name_1, $result->getMessage()), 'horde.error');
     } else {
