@@ -3,15 +3,20 @@
  * Possible strings from weather.com, just to have them in the source for
  * localization reasons.
  *
- * $Horde: horde/lib/Block/weatherdotcom_strings.php,v 1.1.2.6 2006/05/03 17:07:27 jan Exp $
+ * $Horde: horde/lib/Block/weatherdotcom_strings.php,v 1.1.2.7 2007/09/11 12:47:53 jan Exp $
  */
 
 _("AM Clouds");
+_("AM Dizzle");
+_("AM Fog");
 _("AM Light Rain");
 _("AM Light Snow");
 _("AM Rain");
 _("AM Showers");
+_("AM Snow");
 _("AM Snow Showers");
+_("AM Sun");
+_("AM T-Storms");
 _("Clear");
 _("Clearing Late");
 _("Clouds Early");
@@ -20,6 +25,7 @@ _("Fair");
 _("Few Showers");
 _("Few Snow Showers");
 _("Fog");
+_("Foggy");
 _("Freezing Drizzle");
 _("Haze");
 _("Heavy T-Storm");
@@ -37,7 +43,11 @@ _("Mostly Cloudy");
 _("Mostly Cloudy and Windy");
 _("Mostly Sunny");
 _("Partly Cloudy");
+_("PM Clouds");
+_("PM Dizzle");
+_("PM Fog");
 _("PM Light Rain");
+_("PM Light Snow");
 _("PM Rain");
 _("PM Showers");
 _("PM Snow");
@@ -50,6 +60,7 @@ _("Rain Late");
 _("Rain Shower");
 _("Rain and Snow");
 _("Rain to Snow");
+_("Scattered Showers");
 _("Scattered T-Storms");
 _("Showers");
 _("Showers Early");
