@@ -121,10 +121,10 @@ require_once 'Horde/IMAP/Admin.php';
  * );
  * </pre>
  *
- * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33.10.14 2006/08/14 02:48:48 chuck Exp $
+ * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33.10.16 2007/02/05 18:00:59 jan Exp $
  *
- * Copyright 2002-2006 Ilya <mail@krel.org>
- * Copyright 2005-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2002-2007 Ilya <mail@krel.org>
+ * Copyright 2005-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -178,6 +178,80 @@ class Auth_cyrsql extends Auth_sql {
         $this->_admin = &new IMAP_Admin($admin_params);
     }
 
+    /**
+     * Find out if a set of login credentials are valid.
+     *
+     * @access private
+     *
+     * @param string $userId      The userId to check.
+     * @param array $credentials  The credentials to use.
+     *
+     * @return boolean  Whether or not the credentials are valid.
+     */
+    function _authenticate($userId, $credentials)
+    {
+        if (is_a(($result = $this->_connect()), 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            $this->_setAuthError(AUTH_REASON_FAILED);
+            return false;
+        }
+
+        if (!empty($this->_params['domain_field']) &&
+            ($this->_params['domain_field'] != 'none')) {
+            /* Build the SQL query with domain. */
+            $query = sprintf('SELECT * FROM %s WHERE %s = ? AND %s = ?',
+                             $this->_params['table'],
+                             $this->_params['username_field'],
+                             $this->_params['domain_field']);
+            $values = explode('@', $userId);
+        } else {
+            /* Build the SQL query without domain. */
+            $query = sprintf('SELECT * FROM %s WHERE %s = ?',
+                             $this->_params['table'],
+                             $this->_params['username_field']);
+            $values = array($userId);
+        }
+
+        Horde::logMessage('SQL Query by Auth_cyrsql::_authenticate(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+        $result = $this->_db->query($query, $values);
+        if (is_a($result, 'PEAR_Error')) {
+            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
+            $this->_setAuthError(AUTH_REASON_FAILED);
+            return false;
+        }
+
+        $row = $result->fetchRow(DB_GETMODE_ASSOC);
+        if (is_array($row)) {
+            $result->free();
+        } else {
+            $this->_setAuthError(AUTH_REASON_BADLOGIN);
+            return false;
+        }
+
+        if (!$this->_comparePasswords($row[$this->_params['password_field']],
+                                      $credentials['password'])) {
+            $this->_setAuthError(AUTH_REASON_BADLOGIN);
+            return false;
+        }
+
+        $now = time();
+        if (!empty($this->_params['hard_expiration_field']) &&
+            !empty($row[$this->_params['hard_expiration_field']]) &&
+            ($now > $row[$this->_params['hard_expiration_field']])) {
+            $this->_setAuthError(AUTH_REASON_EXPIRED);
+            return false;
+        }
+
+        if (!empty($this->_params['soft_expiration_field']) &&
+            !empty($row[$this->_params['soft_expiration_field']]) &&
+            ($now > $row[$this->_params['soft_expiration_field']])) {
+            $this->_authCredentials['changeRequested'] = true;
+        }
+
+        return true;
+    }
+
     /**
      * Add a set of authentication credentials.
      *
@@ -210,7 +284,7 @@ class Auth_cyrsql extends Auth_sql {
 
             $dbresult = $this->_db->query($query, $values);
             $query = 'INSERT INTO virtual (alias, dest, username, status) VALUES (?, ?, ?, 1)';
-            $values = array($userId, $name, $name);
+            $values = array($userId, $userId, $name);
 
             Horde::logMessage('SQL Query by Auth_cyrsql::addUser(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
@@ -220,24 +294,23 @@ class Auth_cyrsql extends Auth_sql {
             }
         } else {
             $dbresult = parent::addUser($userId, $credentials);
-            $name = $userId;
         }
         if (is_a($dbresult, 'PEAR_Error')) {
             return $dbresult;
         }
 
-        if (!is_a($result = $this->_admin->addMailbox($name), 'PEAR_Error')) {
+        if (!is_a($result = $this->_admin->addMailbox($userId), 'PEAR_Error')) {
             @array_walk($this->_params['folders'],
-                        array($this, '_createSubFolders'), $name);
+                        array($this, '_createSubFolders'), $userId);
         } else {
-            Horde::logMessage('IMAP mailbox creation for ' . $name . ' failed: ' . $result->getMessage(),
+            Horde::logMessage('IMAP mailbox creation for ' . $userId . ' failed: ' . $result->getMessage(),
                               __FILE__, __LINE__, PEAR_LOG_ERR);
             return PEAR::raiseError(sprintf(_("IMAP mailbox creation failed: %s"), $result->getMessage()));
         }
 
         if (isset($this->_params['quota']) && $this->_params['quota'] >= 0) {
             if (!@imap_set_quota($this->_imapStream,
-                                 'user' . $this->_separator . $name,
+                                 'user' . $this->_separator . $userId,
                                  $this->_params['quota'])) {
                 return PEAR::raiseError(sprintf(_("IMAP mailbox quota creation failed: %s"), imap_last_error()));
             }
@@ -271,7 +344,7 @@ class Auth_cyrsql extends Auth_sql {
 
             $dbresult = $this->_db->query($query, $values);
             $query = 'DELETE FROM virtual WHERE dest = ?';
-            $values = array($name);
+            $values = array($userId);
 
             Horde::logMessage('SQL Query by Auth_cyrsql::removeUser(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
@@ -281,7 +354,6 @@ class Auth_cyrsql extends Auth_sql {
             }
         } else {
             $dbresult = parent::removeUser($userId);
-            $name = $userId;
         }
 
         if (is_a($dbresult, 'PEAR_Error')) {
@@ -289,7 +361,7 @@ class Auth_cyrsql extends Auth_sql {
         }
 
         /* Delete IMAP mailbox. */
-        $imapresult = $this->_admin->removeMailbox($name);
+        $imapresult = $this->_admin->removeMailbox($userId);
 
         if (is_a($imapresult, 'PEAR_Error')) {
             return PEAR::raiseError(sprintf(_("IMAP mailbox deletion failed: %s"), $imapresult->getMessage()));
@@ -358,9 +430,11 @@ class Auth_cyrsql extends Auth_sql {
     {
         if (!empty($this->_params['domain_field']) &&
             ($this->_params['domain_field'] != 'none')) {
-            list($userName) = explode('@', $userName);
+            list($userName, $domain) = explode('@', $userName);
+            $this->_admin->addMailbox($userName . $this->_separator . $value . '@' . $domain);
+        } else {
+            $this->_admin->addMailbox($userName . $this->_separator . $value);
         }
-        $this->_admin->addMailbox($userName . $this->_separator . $value);
     }
 
     /**
