@@ -6,10 +6,10 @@ require_once 'Horde/Block/Collection.php';
 /**
  * The Horde_Block_Layout_View class represents the user defined portal layout.
  *
- * $Horde: framework/Block/Block/Layout/View.php,v 1.4.2.3 2006/06/23 04:35:21 chuck Exp $
+ * $Horde: framework/Block/Block/Layout/View.php,v 1.4.2.7 2007/11/22 00:16:14 jan Exp $
  *
- * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
- * Copyright 2003-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2007 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2003-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -45,12 +45,9 @@ class Horde_Block_Layout_View {
     /**
      * Constructor.
      */
-    function Horde_Block_Layout_View($layout = '')
+    function Horde_Block_Layout_View($layout = array())
     {
-        $this->_layout = @unserialize($layout);
-        if (!$this->_layout) {
-            $this->_layout = array();
-        }
+        $this->_layout = $layout;
     }
 
     /**
@@ -79,7 +76,6 @@ class Horde_Block_Layout_View {
                     $block = &Horde_Block_Collection::getBlock($item['app'], $item['params']['type'], $item['params']['params']);
                     $rowspan = $item['height'];
                     $colspan = $item['width'];
-                    $width *= $colspan;
                     for ($i = 0; $i < $item['height']; $i++) {
                         if (!isset($covered[$row_num + $i])) {
                             $covered[$row_num + $i] = array();
@@ -101,10 +97,10 @@ class Horde_Block_Layout_View {
                         include $tplDir . '/portal/block.inc';
                         $html .= ob_get_clean();
                     } else {
-                        $html .= '<td width="' . $width . '%">&nbsp;</td>';
+                        $html .= '<td width="' . ($width * $colspan) . '%">&nbsp;</td>';
                     }
                 } else {
-                    $html .= '<td width="' . $width . '%">&nbsp;</td>';
+                    $html .= '<td width="' . ($width) . '%">&nbsp;</td>';
                 }
             }
             $html .= '</tr>';
