@@ -14,7 +14,7 @@ define('HORDE_COMPRESS_ZIP_DATA', 2);
  * The Horde_Compress_zip class allows ZIP files to be created and
  * read.
  *
- * $Horde: framework/Compress/Compress/zip.php,v 1.11.12.16 2006/06/29 08:34:30 jan Exp $
+ * $Horde: framework/Compress/Compress/zip.php,v 1.11.12.18 2007/01/02 13:54:11 jan Exp $
  *
  * The ZIP compression code is partially based on code from:
  *   Eric Mueller <eric@themepark.com>
@@ -26,9 +26,9 @@ define('HORDE_COMPRESS_ZIP_DATA', 2);
  * The ZIP compression date code is partially based on code from
  *   Peter Listiak <mlady@users.sourceforge.net>
  *
- * Copyright 2000-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2006 Michael Cochrane <mike@graftonhall.co.nz>
- * Copyright 2003-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2000-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Michael Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -343,12 +343,6 @@ class Horde_Compress_zip extends Horde_Compress {
         /* "File data" segment. */
         $fr .= $zdata;
 
-        /* "Data descriptor" segment (optional but necessary if archive is
-           not served as file). */
-        $fr .= pack('V', $crc);
-        $fr .= pack('V', $c_len);
-        $fr .= pack('V', $unc_len);
-
         /* Add this entry to array. */
         $old_offset = strlen(implode('', $contents));
         $contents[] = &$fr;
