@@ -2,15 +2,14 @@
 /**
  * Scatter plot implementation for the Horde_Graph package.
  *
- * $Horde: framework/Graph/Graph/Plot/scatter.php,v 1.3.12.1 2005/01/03 12:19:00 jan Exp $
+ * $Horde: framework/Graph/Graph/Plot/scatter.php,v 1.3.12.5 2007/01/02 13:54:20 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.3.12.1 $
  * @since   Horde 3.0
  * @package Horde_Graph
  */
@@ -31,7 +30,7 @@ class Horde_Graph_Plot_scatter {
         }
     }
 
-    function draw()
+    function draw($minY = false)
     {
         $data = $this->_graph->_data['y'][$this->_dataset];
 
@@ -39,9 +38,11 @@ class Horde_Graph_Plot_scatter {
         $verts = array();
         for ($i = 0; $i < $count; $i++) {
             $x = $i;
-            $y = $data[$i];
-            $this->_graph->translate($x, $y);
-            $this->_graph->img->brush($x, $y, $this->_color, $this->_shape);
+            if ($minY === false || $data[$i] >= $minY) {
+                $y = $data[$i];
+                $this->_graph->translate($x, $y);
+                $this->_graph->img->brush($x, $y, $this->_color, $this->_shape);
+            }
         }
     }
 
