@@ -6,10 +6,10 @@ require_once dirname(__FILE__) . '/Part.php';
  * The MIME_Message:: class provides methods for creating and manipulating
  * MIME email messages.
  *
- * $Horde: framework/MIME/MIME/Message.php,v 1.76.10.12 2006/01/01 21:28:24 jan Exp $
+ * $Horde: framework/MIME/MIME/Message.php,v 1.76.10.14 2007/01/02 13:54:25 jan Exp $
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -205,15 +205,21 @@ class MIME_Message extends MIME_Part {
 
         $addressKeys = array('To', 'Cc', 'Bcc', 'From');
         foreach ($headers as $key => $val) {
-            if (in_array($key, $addressKeys)) {
-                $text = MIME::encodeAddress($val, $charset, $this->_defaultServer);
-                if (is_a($text, 'PEAR_Error')) {
-                    $text = $val;
+            if (is_array($val)) {
+                foreach ($val as $key2 => $val2) {
+                    $headers[$key][$key2] = MIME::wrapHeaders($key, $val2, $this->getEOL());
                 }
             } else {
-                $text = MIME::encode($val, $charset);
+                if (in_array($key, $addressKeys)) {
+                    $text = MIME::encodeAddress($val, $charset, $this->_defaultServer);
+                    if (is_a($text, 'PEAR_Error')) {
+                        $text = $val;
+                    }
+                } else {
+                    $text = MIME::encode($val, $charset);
+                }
+                $headers[$key] = MIME::wrapHeaders($key, $text, $this->getEOL());
             }
-            $headers[$key] = MIME::wrapHeaders($key, $text, $this->getEOL());
         }
 
         return $headers;
