@@ -5,7 +5,7 @@ require_once dirname(__FILE__) . '/Part.php';
 require_once dirname(__FILE__) . '/../MIME.php';
 
 /**
- * $Horde: framework/MIME/MIME/Structure.php,v 1.87.10.19 2006/05/04 18:03:25 slusarz Exp $
+ * $Horde: framework/MIME/MIME/Structure.php,v 1.87.10.23 2007/06/12 17:54:40 slusarz Exp $
  *
  * The MIME_Structure:: class provides methods for dealing with MIME mail.
  *
@@ -15,8 +15,8 @@ require_once dirname(__FILE__) . '/../MIME.php';
  *
  * TODO: Convert to OO
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -160,7 +160,8 @@ class MIME_Structure {
         }
 
         /* Set the default character set. */
-        if (($ob->getCharset() == 'us-ascii') &&
+        if (($ob->getPrimaryType() == 'text') &&
+            ($ob->getCharset() == 'us-ascii') &&
             isset($GLOBALS['mime_structure']['default_charset'])) {
             $ob->setCharset($GLOBALS['mime_structure']['default_charset']);
         }
@@ -207,21 +208,35 @@ class MIME_Structure {
         $pexists = 'if' . $ptype;
 
         if ($part->$pexists) {
+            $attr_list = $rfc2231_list = array();
             foreach ($part->$ptype as $param) {
                 $param->value = str_replace(array("\t", '\"'), array(' ', '"'), $param->value);
-
-                $res = MIME::decodeRFC2231($param->attribute . '=' . $param->value);
-                if ($res) {
-                    $param->attribute = $res['attribute'];
-                    $param->value = $res['value'];
+                /* Look for an asterisk in the attribute name.  If found we
+                 * know we have RFC 2231 information. */
+                $pos = strpos($param->attribute, '*');
+                if ($pos) {
+                    $attr = substr($param->attribute, 0, $pos);
+                    $rfc2231_list[$attr][] = $param->attribute . '=' . $param->value;
+                } else {
+                    $attr_list[$param->attribute] = $param->value;
                 }
-                $field = String::lower($param->attribute);
+            }
+
+            foreach ($rfc2231_list as $val) {
+                $res = MIME::decodeRFC2231(implode(' ', $val));
+                if ($res) {
+                    $attr_list[$res['attribute']] = $res['value'];
+                }
+            }
+
+            foreach ($attr_list as $attr => $val) {
+                $field = String::lower($attr);
                 if ($field == 'type') {
-                    if (($type = MIME::type($param->value))) {
+                    if (($type = MIME::type($val))) {
                         $param_list['type'] = $type;
                     }
                 } else {
-                    $param_list[$field] = $param->value;
+                    $param_list[$field] = $val;
                 }
             }
         }
@@ -405,40 +420,40 @@ class MIME_Structure {
      */
     function parseMIMEHeaders($headers, $decode = true, $lowercase = false)
     {
-        $header = '';
-        $ob = array();
+        $header = $headval = '';
+        $ob = $toprocess = array();
 
         foreach (explode("\n", $headers) as $val) {
-            if ($decode) {
-                $val = MIME::decode($val);
-            }
+            $val = rtrim($val);
             if (preg_match("/^([^\s]+)\:(.*)/", $val, $matches)) {
-                $val = trim($matches[2]);
-                $header = $matches[1];
-                if (isset($ob[$header])) {
-                    if (!is_array($ob[$header])) {
-                        $temp = $ob[$header];
-                        $ob[$header] = array();
-                        $ob[$header][] = $temp;
-                    }
-                    $ob[$header][] = $val;
-                    continue;
+                if (!empty($header)) {
+                    $toprocess[] = array($header, $headval);
                 }
+                $header = $matches[1];
+                $headval = $matches[2];
             } else {
-                $val = ' ' . trim($val);
+                $headval .= ' ' . ltrim($val);
+            }
+        }
+
+        if (!empty($header)) {
+            $toprocess[] = array($header ,$headval);
+        }
+
+        foreach ($toprocess as $val) {
+            if ($decode) {
+                $val[1] = MIME::decode($val[1]);
             }
 
-            if (!empty($header)) {
-                if (isset($ob[$header])) {
-                    if (is_array($ob[$header])) {
-                        end($ob[$header]);
-                        $ob[$header][key($ob[$header])] .= $val;
-                    } else {
-                        $ob[$header] .= $val;
-                    }
-                } else {
-                    $ob[$header] = $val;
+            if (isset($ob[$val[0]])) {
+                if (!is_array($ob[$val[0]])) {
+                    $temp = $ob[$val[0]];
+                    $ob[$val[0]] = array();
+                    $ob[$val[0]][] = $temp;
                 }
+                $ob[$val[0]][] = $val[1];
+            } else {
+                $ob[$val[0]] = $val[1];
             }
         }
 
