@@ -5,9 +5,9 @@
  * set of MIME_Viewer_* drivers which handle the actual rendering,
  * and also a configuration file to map MIME types to drivers.
  *
- * $Horde: framework/MIME/MIME/Viewer.php,v 1.64.10.10 2006/05/05 03:30:23 slusarz Exp $
+ * $Horde: framework/MIME/MIME/Viewer.php,v 1.64.10.12 2007/01/02 13:54:25 jan Exp $
  *
- * Copyright 1999-2006 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -60,21 +60,21 @@ class MIME_Viewer {
      */
     function &factory(&$mime_part, $mime_type = null)
     {
+        $viewer = false;
+
         /* Check that we have a valid MIME_Part object */
         if (!is_a($mime_part, 'MIME_Part')) {
-            return false;
+            return $viewer;
         }
 
         /* Determine driver type from the MIME type */
         if (empty($mime_type)) {
             $mime_type = $mime_part->getType();
             if (empty($mime_type)) {
-                return false;
+                return $viewer;
             }
         }
 
-        $viewer = false;
-
         /* Spawn the relevant driver, and return it (or false on failure) */
         if (($ob = MIME_Viewer::includeDriver($mime_type))) {
             $class = (($ob->module == 'horde') ? '' : $ob->module . '_') . 'MIME_Viewer_' . $ob->driver;
