@@ -6,15 +6,14 @@ require_once 'Horde/Notification/Listener.php';
  * The Notification_Listener_javascript:: class provides functionality for
  * inserting javascript code from the message stack into the page.
  *
- * $Horde: framework/Notification/Notification/Listener/javascript.php,v 1.7.10.1 2005/01/03 12:19:10 jan Exp $
+ * $Horde: framework/Notification/Notification/Listener/javascript.php,v 1.7.10.7 2007/01/02 13:54:34 jan Exp $
  *
- * Copyright 2004-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2004-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.7.10.1 $
  * @since   Horde 3.0
  * @package Horde_Notification
  */
@@ -22,8 +21,6 @@ class Notification_Listener_javascript extends Notification_Listener {
 
     /**
      * Constructor
-     *
-     * @access public
      */
     function Notification_Listener_javascript()
     {
@@ -33,8 +30,6 @@ class Notification_Listener_javascript extends Notification_Listener {
     /**
      * Return a unique identifier for this listener.
      *
-     * @access public
-     *
      * @return string  Unique id.
      */
     function getName()
@@ -46,17 +41,14 @@ class Notification_Listener_javascript extends Notification_Listener {
      * Outputs the javascript code if there are any messages on the
      * 'javascript' message stack and if the 'notify_javascript' option is set.
      *
-     * @access public
-     *
      * @param array &$messageStack     The stack of messages.
-     * @param optional array $options  An array of options.
-     *                                 Options: 'noscript'
+     * @param array $options  An array of options. Options: 'noscript'
      */
     function notify(&$messageStack, $options = array())
     {
         if (count($messageStack)) {
             if (empty($options['noscript'])) {
-                echo '<script language="JavaScript" type="text/javascript">';
+                echo '<script type="text/javascript">';
                 echo "\n<!--\n";
             }
             while ($message = array_shift($messageStack)) {
@@ -71,8 +63,6 @@ class Notification_Listener_javascript extends Notification_Listener {
     /**
      * Outputs one message.
      *
-     * @access public
-     *
      * @param array $message  One message hash from the stack.
      */
     function getMessage($message)
