@@ -17,9 +17,9 @@
  *                                      'pass' => Auth::getCredential('password')));
  * </code>
  *
- * $Horde: framework/RPC/RPC.php,v 1.7.10.8 2006/01/01 21:28:33 jan Exp $
+ * $Horde: framework/RPC/RPC.php,v 1.7.10.11 2007/03/09 17:19:29 jan Exp $
  *
- * Copyright 2002-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2002-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -39,13 +39,27 @@ class Horde_RPC {
     var $_authorize = true;
 
     /**
-     * RPC server constructor
+     * Whether we should exit if auth fails instead of giving the user a
+     * chance to auth.
      *
-     * @access private
-     * @return object   An RPC server instance.
+     * @var boolean
      */
-    function Horde_RPC()
+    var $_noauth = false;
+
+    /**
+     * RPC server constructor.
+     *
+     * @param array $params  A hash containing any additional configuration or
+     *                       connection parameters a subclass might need.
+     *
+     * @return Horde_RPC  An RPC server instance.
+     */
+    function Horde_RPC($params = array())
     {
+        if (!empty($params['noauth'])) {
+            $this->_noauth = true;
+        }
+
         register_shutdown_function(array($this, 'shutdown'));
     }
 
@@ -79,11 +93,19 @@ class Horde_RPC {
         if (isset($_SERVER['PHP_AUTH_USER'])) {
             $user = $_SERVER['PHP_AUTH_USER'];
             $pass = $_SERVER['PHP_AUTH_PW'];
+        } elseif (isset($_SERVER['Authorization'])) {
+            $hash = str_replace('Basic ', '', $_SERVER['Authorization']);
+            $hash = base64_decode($hash);
+            if (strpos($hash, ':') !== false) {
+                list($user, $pass) = explode(':', $hash, 2);
+            }
         }
 
         if (!isset($user)
             || !$auth->authenticate($user, array('password' => $pass))) {
-            header('WWW-Authenticate: Basic realm="Horde RPC"');
+            if (!$this->_noauth) {
+                header('WWW-Authenticate: Basic realm="Horde RPC"');
+            }
             header('HTTP/1.0 401 Unauthorized');
             echo '401 Unauthorized';
             exit;
@@ -187,7 +209,7 @@ class Horde_RPC {
      *                       connection parameters a subclass might need.
      *
      * @return Horde_RPC  The newly created concrete Horde_RPC server instance,
-     *                    or a PEAR_Error on an error.
+     *                    or PEAR_Error on error.
      */
     function &factory($driver, $params = null)
     {
