@@ -11,11 +11,11 @@ define('HORDE_SESSION_READONLY', 2);
  * between Horde applications and keeping track of application
  * configuration information.
  *
- * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.22 2006/05/04 22:35:26 jan Exp $
+ * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.25.2.1 2008/03/07 22:59:33 chuck Exp $
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Jon Parise <jon@horde.org>
- * Copyright 1999-2006 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Jon Parise <jon@horde.org>
+ * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -191,12 +191,12 @@ class Registry {
             $appList = array_keys($this->applications);
             foreach ($appList as $appName) {
                 $app = &$this->applications[$appName];
-                if (($app['status'] == 'heading') ||
-                    ($app['status'] == 'inactive') ||
-                    ($app['status'] == 'admin' && !Auth::isAdmin())) {
+                if ($app['status'] == 'heading') {
                     continue;
                 }
-                if (isset($app['provides'])) {
+                if ($app['status'] != 'inactive' &&
+                    ($app['status'] != 'admin' || Auth::isAdmin()) &&
+                    isset($app['provides'])) {
                     if (is_array($app['provides'])) {
                         foreach ($app['provides'] as $interface) {
                             $this->_interfaces[$interface] = $appName;
@@ -767,8 +767,8 @@ class Registry {
          *  - To all authenticated users if no permission is set on $app.
          *  - To anyone who is allowed by an explicit ACL on $app. */
         if ($checkPerms && !$this->hasPermission($app)) {
-            Horde::logMessage(sprintf('User %s does not have READ permission for %s', Auth::getAuth(), $app), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-            return PEAR::raiseError(sprintf(_("User %s is not authorised for %s."), Auth::getAuth(), $this->applications[$app]['name']), 'permission_denied');
+            Horde::logMessage(sprintf('%s does not have READ permission for %s', Auth::getAuth() ? 'User ' . Auth::getAuth() : 'Guest user', $app), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+            return PEAR::raiseError(sprintf(_('%s is not authorised for %s.'), Auth::getAuth() ? 'User ' . Auth::getAuth() : 'Guest user', $this->applications[$app]['name']), 'permission_denied');
         }
 
         /* Import this application's configuration values. */
@@ -1054,7 +1054,7 @@ class Registry {
         if (isset($GLOBALS['prefs']) &&
             ($theme = $GLOBALS['prefs']->getValue('theme')) &&
             (isset($theme_icons) ||
-             ((@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
+             ((@include $this->get('themesfs', 'horde') . '/' . basename($theme) . '/info.php') &&
               isset($theme_icons))) &&
             in_array($app, $theme_icons)) {
             $img_dir[$app] = $this->get('themesuri', $app) . '/' . $theme . '/graphics';
