@@ -7,10 +7,10 @@ require_once 'PEAR.php';
  * various token generation mediums. It also includes all of the
  * functions for retrieving, storing, and checking tokens.
  *
- * $Horde: framework/Token/Token.php,v 1.33.6.7 2006/01/01 21:28:39 jan Exp $
+ * $Horde: framework/Token/Token.php,v 1.33.6.9 2007/01/02 13:54:45 jan Exp $
  *
- * Copyright 1999-2006 Max Kalika <max@horde.org>
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Max Kalika <max@horde.org>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -75,7 +75,10 @@ class Horde_Token {
     function verify($token)
     {
         $this->purge();
-        if ($this->exists($token)) {
+        $exists = $this->exists($token);
+        if (is_a($exists, 'PEAR_Error')) {
+            return $exists;
+        } elseif ($exists) {
             return false;
         } else {
             return $this->add($token);
