@@ -13,7 +13,7 @@ define('HORDE_ERROR_DRIVER_CONFIG', 2);
 /**
  * The Util:: class provides generally useful methods of different kinds.
  *
- * $Horde: framework/Util/Util.php,v 1.384.6.23 2007/01/11 18:55:50 chuck Exp $
+ * $Horde: framework/Util/Util.php,v 1.384.6.24 2007/03/29 12:34:18 jan Exp $
  *
  * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2007 Jon Parise <jon@horde.org>
@@ -285,11 +285,13 @@ class Util {
      * Returns a url with the 'nocache' parameter added, if the browser is
      * buggy and caches old URLs.
      *
-     * @param string $url  The URL to modify.
+     * @param string $url       The URL to modify.
+     * @param boolean $encode   Encode the argument separator? (since
+     *                          Horde 3.2)
      *
      * @return string  The requested URI.
      */
-    function nocacheUrl($url)
+    function nocacheUrl($url, $encode = true)
     {
         static $rand_num;
 
@@ -302,7 +304,7 @@ class Util {
             if (!isset($rand_num)) {
                 $rand_num = base_convert(microtime(), 10, 36);
             }
-            return Util::addParameter($url, 'nocache', $rand_num);
+            return Util::addParameter($url, 'nocache', $rand_num, $encode);
         } else {
             return $url;
         }
