@@ -2,9 +2,9 @@
 /**
  * VC_svn implementation.
  *
- * Copyright 2000-2006 Anil Madhavapeddy, <anil@recoil.org>
+ * Copyright 2000-2007 Anil Madhavapeddy, <anil@recoil.org>
  *
- * $Horde: framework/VC/VC/svn.php,v 1.28.4.18 2006/05/12 04:47:08 chuck Exp $
+ * $Horde: framework/VC/VC/svn.php,v 1.28.4.20 2007/04/16 05:29:39 chuck Exp $
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @since   Horde 3.0
@@ -218,7 +218,7 @@ class VC_Diff_svn {
             break;
 
         case 'unified':
-            $options .= '--unified=' . (int)$num;
+            $options .= '-p --unified=' . (int)$num;
             break;
 
         case 'column':
@@ -233,7 +233,7 @@ class VC_Diff_svn {
         // TODO: add options for $hr options - however these may not
         // be compatible with some diffs.
         $Q = VC_WINDOWS ? '"' : "'";
-        $command = $rep->getPath('svn') . " diff --diff-cmd " . $rep->getPath('diff') . " -r $rev1:$rev2 -x " . $Q . $options . $Q . ' ' . $file->queryFullPath() . ' 2>&1';
+        $command = $rep->getPath('svn') . " diff --diff-cmd " . $rep->getPath('diff') . " -r $rev1:$rev2 -x " . $Q . $options . $Q . ' ' . $Q . $file->queryFullPath() . $Q . ' 2>&1';
 
         exec($command, $diff, $retval);
         return $diff;
