@@ -25,12 +25,12 @@ if (!function_exists('_')) {
  * The Horde_Test:: class provides functions used in the test scripts
  * used in the various applications (test.php).
  *
- * $Horde: horde/lib/Test.php,v 1.31.4.19 2006/03/28 12:31:13 jan Exp $
+ * $Horde: horde/lib/Test.php,v 1.31.4.23 2007/02/17 03:10:08 slusarz Exp $
  *
- * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Jon Parise <jon@horde.org>
- * Copyright 2002-2006 Brent J. Nordquist <bjn@horde.org>
- * Copyright 2003-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Jon Parise <jon@horde.org>
+ * Copyright 2002-2007 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -66,6 +66,15 @@ class Horde_Test {
      */
     var $_phpver;
 
+    /**
+     * Supported versions of PHP.
+     *
+     * @var array
+     */
+    var $_supported = array(
+        '4.3', '4.4', '5.0', '5.1', '5.2'
+    );
+
     /**
      * Constructor.
      */
@@ -214,7 +223,9 @@ class Horde_Test {
      * KEY:   setting name
      * VALUE: An array with the following entries:
      *        'error'    --  Error Message
-     *        'setting'  --  Boolean - should the setting be on or off
+     *        'setting'  --  Either a boolean (whether setting should be on or
+     *                       off) or 'value', which will simply output the
+     *                       value of the setting.
      * </code>
      *
      * @return string  The HTML output.
@@ -225,15 +236,21 @@ class Horde_Test {
 
         foreach ($settings_list as $key => $val) {
             $entry = array();
-            $result = (ini_get($key) == $val['setting']);
-
-            $entry[] = $key . ' ' . (($val['setting'] === true) ? 'enabled' : 'disabled');
-            $entry[] = $this->_status($result);
-
-            if (!$result) {
-                $entry[] = $val['error'];
+            if (is_bool($val['setting'])) {
+                $result = (ini_get($key) == $val['setting']);
+                $entry[] = $key . ' ' . (($val['setting'] === true) ? 'enabled' : 'disabled');
+                $entry[] = $this->_status($result);
+                if (!$result) {
+                    $entry[] = $val['error'];
+                }
+            } elseif ($val['setting'] == 'value') {
+                $entry[] = $key . ' value';
+                $entry[] = ini_get($key);
+                if (!empty($val['error'])) {
+                    $entry[] = $val['error'];
+                    $entry[] = 1;
+                }
             }
-
             $output .= $this->_outputLine($entry);
         }
 
@@ -570,14 +587,11 @@ FOOTER;
         if ($output->major < '4.3') {
             $output->status = 'This version of PHP is not supported. You need to upgrade to a more recent version.';
             $vers_check = false;
-        } elseif (($output->major == '4.3') ||
-                  ($output->major == '4.4') ||
-                  ($output->major == '5.0') ||
-                  ($output->major == '5.1')) {
+        } elseif (in_array($output->major, $this->_supported)) {
             $output->status = 'You are running a supported version of PHP.';
             $output->status_color = 'green';
         } else {
-            $output->status = 'Wow, a mystical version of PHP from the future. Let <a href="mailto:dev@lists.horde.org">dev@lists.horde.org</a> know what version you have so we can fix this script.';
+            $output->status = 'This version of PHP has not been fully tested with this version of Horde.';
             $output->status_color = 'orange';
         }
 
@@ -648,7 +662,7 @@ FOOTER;
      *
      * @access private
      *
-     * @param array $entry  3 element array.
+     * @param array $entry  Array with the following values:
      * <pre>
      * 1st value: Header
      * 2nd value: Test Result
