@@ -8,6 +8,8 @@
  *      'hostspec'       The ftp server to connect to.</pre>
  *
  * Optional values for $params:<pre>
+ *      'lsformat'       The return formatting from the 'ls' command).
+ *                       Values: 'aix', 'standard' (default)
  *      'maplocalids'    If true and the POSIX extension is available, the
  *                       driver will map the user and group IDs returned from
  *                       the FTP server with the local IDs from the local
@@ -21,12 +23,15 @@
  *                       support, TLS transport-level encryption will be
  *                       negotiated with the server.
  *      'timeout'        If defined, use this value as the timeout for the
- *                       server.</pre>
+ *                       server.
+ *      'type'           The type of the remote FTP server.
+ *                       Possible values: 'unix', 'win', 'netware'
+ *                       By default, we attempt to auto-detect type.</pre>
  *
- * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.21 2006/05/31 04:50:02 slusarz Exp $
+ * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.23 2007/01/02 13:54:48 jan Exp $
  *
- * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2006 Michael Varghese <mike.varghese@ascellatech.com>
+ * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Michael Varghese <mike.varghese@ascellatech.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -75,6 +80,10 @@ class VFS_ftp extends VFS {
      */
     var $_gids = array();
 
+    /**
+     */
+    var $_type;
+
     /**
      * Returns the size of a file.
      *
@@ -417,14 +426,22 @@ class VFS_ftp extends VFS {
         }
 
         $files = array();
-        $type = VFS::strtolower(@ftp_systype($this->_stream));
-        if ($type == 'unknown') {
-            // Go with unix-style listings by default.
-            $type = 'unix';
-        } elseif (strpos($type, 'win') !== false) {
-            $type = 'win';
-        } elseif (strpos($type, 'netware') !== false) {
-            $type = 'netware';
+
+        if (empty($this->_type)) {
+            if (!empty($this->_params['type'])) {
+                $this->_type = $this->_params['type'];
+            } else {
+                $type = VFS::strtolower(@ftp_systype($this->_stream));
+                if ($type == 'unknown') {
+                    // Go with unix-style listings by default.
+                    $type = 'unix';
+                } elseif (strpos($type, 'win') !== false) {
+                    $type = 'win';
+                } elseif (strpos($type, 'netware') !== false) {
+                    $type = 'netware';
+                }
+            }
+            $this->_type = $type;
         }
 
         $olddir = $this->getCurrentDirectory();
@@ -435,7 +452,7 @@ class VFS_ftp extends VFS {
             }
         }
 
-        if ($type == 'unix') {
+        if ($this->_type == 'unix') {
             // If we don't want dotfiles, We can save work here by not
             // doing an ls -a and then not doing the check later (by
             // setting $dotfiles to true, the if is short-circuited).
@@ -471,7 +488,8 @@ class VFS_ftp extends VFS {
         foreach ($list as $line) {
             $file = array();
             $item = preg_split('/\s+/', $line);
-            if ($type == 'unix' || ($type == 'win' && !preg_match('|\d\d-\d\d-\d\d|', $item[0]))) {
+            if (($this->_type == 'unix') ||
+                (($this->_type == 'win') && !preg_match('|\d\d-\d\d-\d\d|', $item[0]))) {
                 if (count($item) < 8 || substr($line, 0, 5) == 'total') {
                     continue;
                 }
@@ -492,7 +510,13 @@ class VFS_ftp extends VFS {
                     $file['owner'] = $item[2];
                     $file['group'] = $item[3];
                 }
-                $file['name'] = substr($line, strpos($line, sprintf("%s %2s %5s", $item[5], $item[6], $item[7])) + 13);
+
+                if (!empty($this->_params['lsformat']) &&
+                    ($this->_params['lsformat'] == 'aix')) {
+                    $file['name'] = substr($line, strpos($line, sprintf("%s %2s %-5s", $item[5], $item[6], $item[7])) + 13);
+                } else {
+                    $file['name'] = substr($line, strpos($line, sprintf("%s %2s %5s", $item[5], $item[6], $item[7])) + 13);
+                }
 
                 // Filter out '.' and '..' entries.
                 if (preg_match('/^\.\.?\/?$/', $file['name'])) {
@@ -550,7 +574,7 @@ class VFS_ftp extends VFS {
                 } else {
                     $file['date'] = strtotime('00:00:00' . $item[5] . ' ' . $item[6] . ' ' . $item[7]);
                 }
-            } elseif ($type == 'netware') {
+            } elseif ($this->_type == 'netware') {
                 $file = Array();
                 $file['perms'] = $item[1];
                 $file['owner'] = $item[2];
