@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/services/shares/edit.php,v 1.26.10.8 2006/05/01 21:16:41 chuck Exp $
+ * $Horde: horde/services/shares/edit.php,v 1.26.10.11 2007/11/23 16:49:25 jan Exp $
  *
- * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -59,7 +59,7 @@ case 'editform':
 
         // Process owner and owner permissions.
         $old_owner = $share->get('owner');
-        $new_owner = Util::getFormData('owner', $old_owner);
+        $new_owner = Auth::addHook(Util::getFormData('owner', $old_owner));
         if ($old_owner !== $new_owner && !empty($new_owner)) {
             if ($old_owner != Auth::getAuth() && !Auth::isAdmin()) {
                 $notification->push(_("Only the owner or system administrator may change ownership or owner permissions for a share"), 'horde.error');
@@ -163,6 +163,8 @@ case 'editform':
         $u_delete = Util::getFormData('u_delete');
 
         foreach ($u_names as $key => $user) {
+            // Apply backend hooks
+            $user = Auth::addHook($user);
             // If the user is empty, or we've already set permissions
             // via the owner_ options, don't do anything here.
             if (empty($user) || $user == $new_owner) {
@@ -227,6 +229,12 @@ case 'editform':
 
         $share->setPermission($perm, false);
         $share->save();
+
+        if (Util::getFormData('save_and_finish')) {
+            Util::closeWindowJS();
+            exit;
+        }
+
         $notification->push(sprintf(_("Updated \"%s\"."), $share->get('name')), 'horde.success');
         $form = 'edit.inc';
     }
