@@ -3,12 +3,12 @@
  *
  * Provides the javascript class to create dynamic trees.
  *
- * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (GPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * $Horde: horde/templates/javascript/tree.js,v 1.62.2.11 2006/01/01 21:29:15 jan Exp $
+ * $Horde: horde/templates/javascript/tree.js,v 1.62.2.13 2007/03/22 21:29:49 slusarz Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @package Horde_Tree
@@ -302,7 +302,7 @@ Horde_Tree.prototype._setLabel = function(nodeId)
 
         return '<a' + urlClass + ' href="' + this.nodes[nodeId]['url'] + '"' + target + onclick + '>' + this._setNodeIcon(nodeId) + label + '</a>';
     } else {
-        return '<span class="toggle" onclick="' + this._instanceName + '.toggle(\'' + nodeId + '\')">' + this._setNodeIcon(nodeId) + label + '</span>';
+        return '<span class="toggle" onclick="' + this._instanceName + '.toggle(\'' + nodeId.replace(/'/, "\\'") + '\')">' + this._setNodeIcon(nodeId) + label + '</span>';
     }
 }
 
@@ -316,7 +316,7 @@ Horde_Tree.prototype._setNodeToggle = function(nodeId)
         if (this.renderStatic) {
             return '';
         } else {
-            attrib = ' style="cursor:pointer" onclick="' + this._instanceName + '.toggle(\'' + nodeId + '\')"';
+            attrib = ' style="cursor:pointer" onclick="' + this._instanceName + '.toggle(\'' + nodeId.replace(/'/, "\\'") + '\')"';
         }
     } else if (this.nodes[nodeId]['indent'] != '0' &&
                typeof(this.nodes[nodeId]['children']) == 'undefined') {
@@ -337,7 +337,7 @@ Horde_Tree.prototype._setNodeToggle = function(nodeId)
             this.dropline[this.nodes[nodeId]['indent']] = false;
         }
         if (!this.renderStatic) {
-            attrib = ' style="cursor:pointer" onclick="' + this._instanceName + '.toggle(\'' + nodeId + '\')"';
+            attrib = ' style="cursor:pointer" onclick="' + this._instanceName + '.toggle(\'' + nodeId.replace(/'/, "\\'") + '\')"';
         }
     } else {
         // Top level node with no children.
