@@ -1,10 +1,10 @@
 <?php
 /**
- * $Horde: horde/test.php,v 1.122.6.17 2006/06/10 23:16:51 chuck Exp $
+ * $Horde: horde/test.php,v 1.122.6.21 2007/02/16 06:50:56 slusarz Exp $
  *
- * Copyright 2002-2006 Brent J. Nordquist <bjn@horde.org>
- * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Jon Parise <jon@horde.org>
+ * Copyright 2002-2007 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -101,10 +101,6 @@ $setting_list = array(
         'setting' => false,
         'error' => 'magic_quotes_runtime may cause problems with database inserts, etc. Turn it off.'
     ),
-    'memory_limit' => array(
-        'setting' => false,
-        'error' => 'If PHP\'s internal memory limit is turned on and if not set high enough Horde will not be able to handle large data items (e.g. large mail attachments in IMP). If possible, you should disable the PHP memory limit by recompiling PHP <em>without</em> the "--enable-memory-limit" flag. If this is not possible, then you should set the value of memory_limit in php.ini to a sufficiently high value (Current value of memory_limit: ' . ini_get('memory_limit') . ').'
-    ),
     'safe_mode' => array(
         'setting' => false,
         'error' => 'If safe_mode is enabled, Horde cannot set enviroment variables, which means Horde will be unable to translate the user interface into different languages.'
@@ -116,9 +112,30 @@ $setting_list = array(
     'session.auto_start' => array(
         'setting' => false,
         'error' => 'Horde won\'t work with automatically started sessions, because it explicitly creates new session when necessary to protect against session fixations.'
-    )
+    ),
+    'zlib.output_compression' => array(
+        'setting' => false,
+        'error' => 'You should not enable output compression unconditionally because some browsers and scripts don\'t work well with output compression. Enable compression in Horde\'s configuration instead, so that we have full control over the conditions where to enable and disable it.'
+    ),
+    'zend_accelerator.compress_all' => array(
+        'setting' => false,
+        'error' => 'You should not enable output compression unconditionally because some browsers and scripts don\'t work well with output compression. Enable compression in Horde\'s configuration instead, so that we have full control over the conditions where to enable and disable it.'
+    ),
 );
 
+/* As of PHP 5.2.1, memory limit is enabled by default. */
+if (version_compare(PHP_VERSION, '5.2.1') != -1) {
+    $setting_list['memory_limit'] = array(
+        'setting' => 'value',
+        'error' => 'If PHP\'s internal memory limit is not set high enough Horde will not be able to handle large data items (e.g. large mail attachments in IMP). You should set the value of memory_limit in php.ini to a sufficiently high value - at least 64M is recommended.'
+    );
+} else {
+    $setting_list['memory_limit'] = array(
+        'setting' => false,
+        'error' => 'If PHP\'s internal memory limit is turned on and if not set high enough Horde will not be able to handle large data items (e.g. large mail attachments in IMP). If possible, you should disable the PHP memory limit by recompiling PHP <em>without</em> the "--enable-memory-limit" flag. If this is not possible, then you should set the value of memory_limit in php.ini to a sufficiently high value (Current value of memory_limit: ' . ini_get('memory_limit') . ').'
+    );
+}
+
 
 /* PEAR */
 $pear_list = array(
@@ -285,6 +302,7 @@ if (!empty($_GET['mode'])) {
     }
 }
 
+$test_app = 'horde';
 require TEST_TEMPLATES . 'header.inc';
 require TEST_TEMPLATES . 'version.inc';
 
